@@ -98,7 +98,7 @@ def zinc_plot(res_zinc:pd.DataFrame, p_val, adj:str = 'None', dir:str = 'results
 
 
 
-    count['%'] = count['n']/sum(count['n'])*100
+    count['%'] = count['n']/len(np.unique(df3['gene_name']))*100
     count['p-val'] = None
 
     for n, p in enumerate(count['n']):   
